@@ -22,7 +22,7 @@ using namespace Rcpp;
 class Distribution
 {
 public:
-	explicit Distribution(mat xsep, int kr, int kc, int nbSEM);
+	explicit Distribution(mat xsep, int kr, int kc, int nbSEM, int seed);
 	Distribution();
 	virtual ~Distribution();
 	virtual void missingValuesInit();
@@ -41,6 +41,7 @@ public:
 	virtual void putParamsToZero();
 	virtual double computeICL(int i, int d, int k, int h);
 	bool verif(mat V, mat W, int nbindmini);
+	int verification(const mat& V, const mat& W, int nbindmini);
 	mat colkmeans();
 	double getDistance(vec &a, vec &b);
 	mat returnXhat();
@@ -54,6 +55,7 @@ protected:
 	int _kr;
 	int _kc;
 	int _nbSEM;
+	int _seed;
 	
 };
 
